@@ -1,18 +1,40 @@
 /*
- * Harness.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2007-2008 Operational Dynamics Consulting Pty Ltd
+ * Copyright © 2007-2010 Operational Dynamics Consulting, Pty Ltd
  *
- * The code in this file, and the program it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" See the LICENCE file for the terms governing usage and
- * redistribution.
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
  */
-
 import java.io.FileNotFoundException;
 import java.io.IOException;
 
 import org.freedesktop.bindings.Environment;
+import org.freedesktop.cairo.Illustration;
+import org.freedesktop.cairo.IllustrationOperatorAdd;
+import org.freedesktop.cairo.IllustrationOperatorAtop;
+import org.freedesktop.cairo.IllustrationOperatorClear;
+import org.freedesktop.cairo.IllustrationOperatorDest;
+import org.freedesktop.cairo.IllustrationOperatorDestAtop;
+import org.freedesktop.cairo.IllustrationOperatorDestIn;
+import org.freedesktop.cairo.IllustrationOperatorDestOut;
+import org.freedesktop.cairo.IllustrationOperatorDestOver;
+import org.freedesktop.cairo.IllustrationOperatorIn;
+import org.freedesktop.cairo.IllustrationOperatorOut;
+import org.freedesktop.cairo.IllustrationOperatorOver;
+import org.freedesktop.cairo.IllustrationOperatorSaturate;
+import org.freedesktop.cairo.IllustrationOperatorSource;
+import org.freedesktop.cairo.IllustrationOperatorXOR;
 import org.freedesktop.cairo.SnapshotContextArc;
 import org.freedesktop.cairo.SnapshotContextArcNegative;
 import org.freedesktop.cairo.SnapshotContextLine;
@@ -20,6 +42,7 @@ import org.freedesktop.cairo.SnapshotContextRectangle;
 import org.freedesktop.cairo.SnapshotMatrixRotate;
 import org.freedesktop.cairo.SnapshotMatrixScale;
 import org.freedesktop.cairo.SnapshotMatrixTranslate;
+import org.freedesktop.cairo.Surface;
 import org.gnome.gdk.Pixbuf;
 import org.gnome.gdk.PixbufFormat;
 import org.gnome.gtk.Gtk;
@@ -27,11 +50,15 @@ import org.gnome.gtk.Snapshot;
 import org.gnome.gtk.SnapshotAboutDialog;
 import org.gnome.gtk.SnapshotArrow;
 import org.gnome.gtk.SnapshotButton;
+import org.gnome.gtk.SnapshotCalendar;
 import org.gnome.gtk.SnapshotComboBox;
 import org.gnome.gtk.SnapshotEntryCompletion;
+import org.gnome.gtk.SnapshotEntryIcon;
 import org.gnome.gtk.SnapshotFileChooserDialog;
 import org.gnome.gtk.SnapshotHScale;
+import org.gnome.gtk.SnapshotInfoBar;
 import org.gnome.gtk.SnapshotInfoMessageDialog;
+import org.gnome.gtk.SnapshotLinkButton;
 import org.gnome.gtk.SnapshotNotebook;
 import org.gnome.gtk.SnapshotQuestionMessageDialog;
 import org.gnome.gtk.SnapshotRadioButton;
@@ -74,6 +101,7 @@ public final class Harness
         Process settingsDaemon = null;
         final Pixbuf logo;
         final Class<?>[] demos;
+        final Class<?>[] illustrationdemos;
 
         try {
             r = Runtime.getRuntime();
@@ -139,34 +167,55 @@ public final class Harness
              */
 
             demos = new Class[] {
-                    SnapshotWindow.class,
-                    SnapshotStatusbar.class,
-                    SnapshotButton.class,
-                    SnapshotInfoMessageDialog.class,
-                    SnapshotQuestionMessageDialog.class,
-                    SnapshotTreeView.class,
-                    SnapshotTreeStore.class,
-                    SnapshotFileChooserDialog.class,
-                    SnapshotAboutDialog.class,
-                    SnapshotHScale.class,
-                    SnapshotVScale.class,
-                    SnapshotRadioButton.class,
-                    SnapshotComboBox.class,
-                    SnapshotArrow.class,
-                    SnapshotNotebook.class,
-                    SnapshotTextComboBox.class,
-                    SnapshotTextComboBoxEntry.class,
-                    SnapshotContextLine.class,
-                    SnapshotTextView.class,
-                    SnapshotTextViewBorderWindows.class,
-                    SnapshotTextViewSpelling.class,
-                    SnapshotContextArc.class,
-                    SnapshotContextArcNegative.class,
-                    SnapshotMatrixRotate.class,
-                    SnapshotMatrixScale.class,
-                    SnapshotMatrixTranslate.class,
-                    SnapshotContextRectangle.class,
-                    SnapshotEntryCompletion.class
+                SnapshotWindow.class,
+                SnapshotStatusbar.class,
+                SnapshotButton.class,
+                SnapshotInfoMessageDialog.class,
+                SnapshotQuestionMessageDialog.class,
+                SnapshotTreeView.class,
+                SnapshotTreeStore.class,
+                SnapshotFileChooserDialog.class,
+                SnapshotAboutDialog.class,
+                SnapshotHScale.class,
+                SnapshotVScale.class,
+                SnapshotRadioButton.class,
+                SnapshotComboBox.class,
+                SnapshotArrow.class,
+                SnapshotNotebook.class,
+                SnapshotCalendar.class,
+                SnapshotTextComboBox.class,
+                SnapshotTextComboBoxEntry.class,
+                SnapshotContextLine.class,
+                SnapshotTextView.class,
+                SnapshotTextViewBorderWindows.class,
+                SnapshotTextViewSpelling.class,
+                SnapshotContextArc.class,
+                SnapshotContextArcNegative.class,
+                SnapshotMatrixRotate.class,
+                SnapshotMatrixScale.class,
+                SnapshotMatrixTranslate.class,
+                SnapshotContextRectangle.class,
+                SnapshotEntryCompletion.class,
+                SnapshotEntryIcon.class,
+                SnapshotLinkButton.class,
+                SnapshotInfoBar.class
+            };
+
+            illustrationdemos = new Class[] {
+                IllustrationOperatorIn.class,
+                IllustrationOperatorClear.class,
+                IllustrationOperatorSource.class,
+                IllustrationOperatorOver.class,
+                IllustrationOperatorOut.class,
+                IllustrationOperatorAtop.class,
+                IllustrationOperatorDest.class,
+                IllustrationOperatorDestOver.class,
+                IllustrationOperatorDestIn.class,
+                IllustrationOperatorDestOut.class,
+                IllustrationOperatorDestAtop.class,
+                IllustrationOperatorXOR.class,
+                IllustrationOperatorAdd.class,
+                IllustrationOperatorSaturate.class
             };
 
             /*
@@ -211,6 +260,37 @@ public final class Harness
 
                 w.hide();
             }
+            /* Now for the Illustrations */
+            for (int i = 0; i < illustrationdemos.length; i++) {
+                final Illustration demo;
+                final String f;
+                final Surface s;
+
+                /*
+                 * Instantiate here (as opposed to above when specifying the
+                 * array) so that each one takes its resources in turn. We ran
+                 * into problems with all sorts of cruft being on the display
+                 * when doing it otherwise.
+                 */
+                try {
+                    demo = (Illustration) illustrationdemos[i].newInstance();
+                } catch (InstantiationException e) {
+                    e.printStackTrace();
+                    continue;
+                } catch (IllegalAccessException e) {
+                    e.printStackTrace();
+                    continue;
+                }
+
+                demo.illustrate();
+
+                s = demo.getSurface();
+                f = demo.getFilename();
+
+                System.out.println("WRITE\t" + f);
+
+                s.writeToPNG(f);
+            }
         } finally {
             /*
              * And now tear down the virtual X server and friends. This is far
